
local rematch = Rematch
local browser = rematch.browser
local roster = rematch.roster
local settings

browser.typeMode = 1

function rematch:InitializeBrowser()

	settings = RematchSettings

	-- setup list scrollFrame
	local scrollFrame = browser.list.scrollFrame
	scrollFrame.update = rematch.UpdateBrowserList
	scrollFrame.stepSize = 180
	HybridScrollFrame_CreateButtons(scrollFrame, "RematchBrowserListButtonTemplate") -- , 2, 1, "TOPLEFT", "TOPLEFT", 0, 2, "TOP", "BOTTOM")
	local scrollBar = scrollFrame.scrollBar
	scrollBar.doNotHide = true
	scrollBar.trackBG:SetPoint("TOPLEFT",-2,25)
	scrollBar.trackBG:SetPoint("BOTTOMRIGHT",2,-25)
	scrollBar.trackBG:SetTexture("Interface\\ChatFrame\\ChatFrameBackground")
	scrollBar.trackBG:SetGradientAlpha("HORIZONTAL",.125,.125,.125,1,.05,.05,.05,1)

	-- when scrolling with the mousewheel, update the card to the new pet under the mouse
	scrollBar:HookScript("OnValueChanged",function(self)
		if MouseIsOver(scrollFrame) then
			local focus = GetMouseFocus()
			local petID = focus and focus.petID
			if petID then
				rematch:ShowFloatingPetCard(petID,focus,true)
			end
		end
	end)

	-- set texture and position for typebar pet type buttons
	for i=1,10 do
		local button = browser.typeBar.buttons[i]
		button.icon:SetTexture("Interface\\Icons\\Icon_PetFamily_"..PET_TYPE_SUFFIX[i])
		button:SetPoint("BOTTOMLEFT",(i-1)*20+5,5)
	end

	-- color browser tabs
	browser.typeBar.tabs[1].selected.left:SetVertexColor(.5,.41,0) -- type tab = yellow
	browser.typeBar.tabs[1].selected.middle:SetVertexColor(.5,.41,0)
	browser.typeBar.tabs[1].selected.right:SetVertexColor(.5,.41,0)

	browser.typeBar.tabs[2].selected.left:SetVertexColor(0,.5,0) -- strong tab = green
	browser.typeBar.tabs[2].selected.middle:SetVertexColor(0,.5,0)
	browser.typeBar.tabs[2].selected.right:SetVertexColor(0,.5,0)

	browser.typeBar.tabs[3].selected.left:SetVertexColor(.5,0,0) -- tough tab = red
	browser.typeBar.tabs[3].selected.middle:SetVertexColor(.5,0,0)
	browser.typeBar.tabs[3].selected.right:SetVertexColor(.5,0,0)

end

-- shuffles stuff around depending on whether rematch is on left or right of screen
function rematch:UpdateBrowserPosition()
	if rematch.journalOpen and settings.browserOpen and settings.PrioritizeBrowser then
		HideUIPanel(PetJournalParent)
	end
	browser:ClearAllPoints()
	local queue = rematch.queue
	queue:ClearAllPoints()
	local buttons = RematchHelpButton
	buttons:ClearAllPoints()
	local teams = Rematch.drawer.teams
	teams:ClearAllPoints()
	if rematch.toggle:GetRight()*rematch.toggle:GetEffectiveScale() < (UIParent:GetWidth()*UIParent:GetEffectiveScale())/2 then
		-- left side of screen
		browser:SetPoint("BOTTOMLEFT",rematch,"BOTTOMRIGHT",-3,0)
		queue:SetPoint("BOTTOMRIGHT",rematch,"BOTTOMLEFT",3,0)
		buttons:SetPoint("BOTTOMLEFT",rematch.drawer,"BOTTOMLEFT",14,10)
		teams:SetPoint("TOPRIGHT",rematch.drawer,"TOPRIGHT",-10,-4)
		rematch.panel.shadow:SetTexCoord(0,1,0,1)
	else
		-- right side of screen
		browser:SetPoint("BOTTOMRIGHT",rematch,"BOTTOMLEFT",3,0)
		queue:SetPoint("BOTTOMLEFT",rematch,"BOTTOMRIGHT",-3,0)
		buttons:SetPoint("BOTTOMRIGHT",rematch.drawer,"BOTTOMRIGHT",-14,2)
		teams:SetPoint("TOPLEFT",rematch.drawer,"TOPLEFT",10,-4)
		rematch.panel.shadow:SetTexCoord(1,0,0,1)
	end
	local drawerOpen = rematch.drawer:IsVisible()
	browser:SetShown((settings.browserOpen and not rematch.journalOpen)and drawerOpen)

	if drawerOpen and settings.queueOpen then
		queue:Show()
	elseif not drawerOpen and settings.ShowSidePanel then
		rematch:PositionQueueForSidePanel()
	else
		queue:Hide()
	end
end

-- this is for the key binding: toggle whole window with browser
function rematch:ToggleBrowser()
	if rematch:IsVisible() and rematch.browser:IsVisible() then
		rematch:Hide()
	else
		rematch:RematchBrowserButton()
	end
end

-- when hitting the Pets button on main window, if collapsed always open browser.
-- if drawer open, toggle browser
function rematch:RematchBrowserButton()
	local showBrowser
	if not browser:IsVisible() and PetJournal and PetJournal:IsVisible() then
		HideUIPanel(PetJournalParent)
		showBrowser = true
	end
	if not rematch:IsVisible() then
		rematch:Toggle()
		showBrowser = true
	end
	if not InCombatLockdown() then
		if not rematch.drawer:IsVisible() then
			settings.browserOpen = true
			rematch:ToggleDrawer()
		else
			settings.browserOpen = showBrowser or not settings.browserOpen
			rematch:UpdateBrowserPosition()
		end
	end
end

function rematch:BrowserOnShow()

	if select(2,C_PetJournal.GetNumPets())==0 then
		-- if pets not loaded, come back in half a second to try again
		rematch:StartTimer("PetsRanAwayFromBrowser",0.5,rematch.BrowserOnShow)
		return
	end

	if PetJournal and PetJournal:IsVisible() then
		HideUIPanel(PetJournalParent)
	end
	rematch:HideFloatingPetCard(true)

	if not browser.filterMenu then
		browser.filterMenu = CreateFrame("Frame","RematchBrowserFilterDropDown",browser.filterButton,"UIDropDownMenuTemplate")
		UIDropDownMenu_Initialize(browser.filterMenu,rematch.BrowserFilterDropDownMenu,"MENU")
	end

	C_PetJournal.ClearSearchFilter() -- clear live search
	C_PetJournal.SetFlagFilter(LE_PET_JOURNAL_FLAG_FAVORITES,false) -- clear live favorites
	rematch:ClearAllTypeFilters()
	rematch:ClearSearchBox()
	roster:ClearRarityFilter()
	roster:SetCurrentZoneFilter(nil)
	roster:SetFavoriteFilter(nil)
	rematch:BrowserScrollToTop()
	rematch:UpdateBrowser()
end

function rematch:ClearAllTypeFilters()
	for i=1,3 do
		roster:ClearTypeFilter(i)
	end
	browser.typeMode = 1
end

function rematch:ClearSearchBox()
	local searchBox = Rematch.browser.searchBox
	searchBox:SetText("")
	searchBox:GetScript("OnEditFocusLost")(searchBox)
end

function rematch:UpdateBrowser()
	if browser:IsVisible() then
		roster:Update()
		rematch:UpdateBrowserList()
		rematch:UpdateTypeBar()
		rematch:UpdateBrowserResults()
	end
end

-- this updates the HybridScrollFrame with roster's pets, the big list of pets
function rematch:UpdateBrowserList()
	local numData = roster:GetNumPets()
	local scrollFrame = browser.list.scrollFrame
	local offset = HybridScrollFrame_GetOffset(scrollFrame)
	local buttons = scrollFrame.buttons
	local isBreedable = IsAddOnLoaded("BattlePetBreedID")
	for i=1, #buttons do
		local index = i + offset
		local button = buttons[i]
		button.index = index
		if ( index <= numData) then
			button:SetID(index)
			button.favorite:Hide()
			button.dead:Hide()
			local petID = roster:GetPetByIndex(index)
			button.petID = petID
			if type(petID)=="string" then -- an owned petID
				local speciesID,customName,level,_,_,_,favorite,speciesName,icon,petType = C_PetJournal.GetPetInfoByPetID(petID)
				button.name:SetText(customName or speciesName)
				button.icon:SetTexture(icon)
				button.level:SetText(level)
				button.type:SetTexture("Interface\\PetBattles\\PetIcon-"..PET_TYPE_SUFFIX[petType])
				if favorite then
					button.favorite:Show()
				end
				local health,maxHealth,_,_,rarity = C_PetJournal.GetPetStats(petID)
		    local r,g,b = ITEM_QUALITY_COLORS[rarity-1].r, ITEM_QUALITY_COLORS[rarity-1].g, ITEM_QUALITY_COLORS[rarity-1].b
		    button.rarity:SetGradientAlpha("VERTICAL",r,g,b,1,r,g,b,0)
		    button.rarity:Show()
				if health<1 and maxHealth>0 then
					button.dead:Show()
				end
		    button.icon:SetDesaturated(0)
		    button.type:SetDesaturated(0)
		    button.name:SetTextColor(1,.82,.2)
				button.leveling:SetShown(rematch:IsPetLeveling(petID))
				if isBreedable then
					button.breed:SetText(GetBreedID_Journal(petID) or "")
					button.name:SetPoint("BOTTOMRIGHT",-24,2)
				else
					button.breed:SetText("")
					button.name:SetPoint("BOTTOMRIGHT",-8,2)
				end
			elseif type(petID)=="number" then -- an unowned species
				local name,icon,petType = C_PetJournal.GetPetInfoBySpeciesID(petID)
				button.name:SetText(name)
				button.icon:SetTexture(icon)
				button.level:SetText("")
				button.type:SetTexture("Interface\\PetBattles\\PetIcon-"..PET_TYPE_SUFFIX[petType])
				button.favorite:Hide()
				button.leveling:Hide()
		    button.rarity:Hide()
		    button.icon:SetDesaturated(1)
		    button.type:SetDesaturated(1)
		    button.name:SetTextColor(.8,.8,.8)
				button.breed:SetText("")
				button.name:SetPoint("BOTTOMRIGHT",-8,2)
			end
			button:Show()
		else
			button:Hide()
		end

	end
	HybridScrollFrame_Update(scrollFrame, 30*numData, 30)

	-- possible fix for bug reported http://www.warcraftpets.com/community/forum/viewtopic.php?f=3&t=9205&start=80#p78632
	-- i can't reproduce it. the hybridscrollframe is supposed to reset itself when its height is less than range
	if not scrollFrame.scrollBar:IsEnabled() and HybridScrollFrame_GetOffset(scrollFrame)~=0 then
		rematch:BrowserScrollToTop()
	end
end

function rematch:BrowserScrollToTop()
	local scrollFrame = rematch.browser.list.scrollFrame
	HybridScrollFrame_SetOffset(scrollFrame,0)
	scrollFrame.scrollBar:SetValue(0)
end

function rematch:BrowserScrollToBottom()
	local scrollFrame = rematch.browser.list.scrollFrame
	local offset = roster:GetNumPets()
	HybridScrollFrame_SetOffset(scrollFrame,offset)
	scrollFrame.scrollBar:SetValue(offset*scrollFrame.scrollBar.buttonHeight)
end

function rematch:BrowserPetOnEnter()
	if self.petID and not rematch.disableOnEnters then
		rematch:ShowFloatingPetCard(self.petID,self,true)
	end
end

function rematch:BrowserPetOnLeave()
	rematch:HideFloatingPetCard()
end

function rematch:BrowserPetOnDrag()
	if self.petID then
		C_PetJournal.PickupPet(self.petID)
	end
end

function rematch:BrowserPetOnClick(button)
	if button=="RightButton" and self.petID then
		rematch.dropDownPetID = self.petID
		rematch.dropDownPetSlot = nil
		rematch:ShowDropDown(5)
	else
		local cardID = RematchFloatingPetCard.petID

		if IsModifiedClick("CHATLINK") and type(cardID)=="string" then
			ChatEdit_InsertLink(C_PetJournal.GetBattlePetLink(cardID))
			return
		end

		rematch:LockFloatingPetCard()
		if self.petID ~= cardID then
			rematch:ShowFloatingPetCard(self.petID,self,true)
			rematch:LockFloatingPetCard() -- lock it again
		end
	end
end

function rematch:BrowserPetOnDoubleClick(button)
	if self.petID then
		C_PetJournal.SummonPetByGUID(self.petID)
		rematch:HideFloatingPetCard(true)
	end
end

--[[ Type Bar ]]

function rematch:ToggleTypeBar()
	settings.UseTypeBar = not settings.UseTypeBar
	rematch:UpdateTypeBar()
end

function rematch:UpdateTypeBar()
	local typeBar = browser.typeBar
	if settings.UseTypeBar then -- show typeBar

		browser.toggle:SetNormalTexture("Interface\\ChatFrame\\UI-ChatIcon-ScrollUp-Up")
		browser.toggle:SetPushedTexture("Interface\\ChatFrame\\UI-ChatIcon-ScrollUp-Down")
		browser.list:SetPoint("TOPLEFT",typeBar,"BOTTOMLEFT",3,2)

		-- update tabs
		for i=1,3 do
			browser.typeBar.tabs[i].selected:SetShown(i==browser.typeMode)
			browser.typeBar.tabs[i]:SetNormalFontObject(i==browser.typeMode and "GameFontHighlightSmall" or "GameFontNormalSmall")
			browser.typeBar.tabs[i].hasStuff:SetShown(not roster:IsTypeFilterClear(i))
		end

		-- color border to match tab color
		if browser.typeMode==1 then
			browser.typeBar:SetBackdropBorderColor(1,.82,0)
		elseif browser.typeMode==2 then
			browser.typeBar:SetBackdropBorderColor(0,.75,0)
		elseif browser.typeMode==3 then
			browser.typeBar:SetBackdropBorderColor(.75,0,0)
		end

		-- update type buttons
		local modeClear = roster:IsTypeFilterClear(browser.typeMode)
		for i=1,10 do
			local isChecked = roster:GetTypeFilter(browser.typeMode,i)
			browser.typeBar.buttons[i].icon:SetDesaturated(isChecked and 0 or not modeClear)
			if browser.typeMode>1 then
				browser.typeBar.buttons[i]:SetChecked(isChecked)
			else
				browser.typeBar.buttons[i]:SetChecked(not modeClear and isChecked)
			end
		end

		-- show clear button if any tab has stuff
		if not roster:IsTypeFilterClear() or not roster:IsTypeFilterClear(2) or not roster:IsTypeFilterClear(3) then
			browser.typeBar.clear:Show()
		else
			browser.typeBar.clear:Hide()
		end

		typeBar:Show()

	else -- hide typeBar
		browser.toggle:SetNormalTexture("Interface\\ChatFrame\\UI-ChatIcon-ScrollDown-Up")
		browser.toggle:SetPushedTexture("Interface\\ChatFrame\\UI-ChatIcon-ScrollDown-Down")
		browser.list:SetPoint("TOPLEFT",browser,"TOPLEFT",8,-26)
		typeBar:Hide()
	end

end

-- the 10 type buttons in the typebar
function rematch:BrowserTypeButtonOnClick()
	roster:SetTypeFilter(browser.typeMode,self:GetID(),self:GetChecked())
	rematch:UpdateBrowser()
end

-- clear button in typebar
function rematch:TypeBarClearOnClick()
	if roster:IsTypeFilterClear(browser.typeMode) then -- if tab already clear, clear all tabs and move to type tab
		rematch:ClearAllTypeFilters()
	else -- otherwise clear just the current tab
		roster:ClearTypeFilter(browser.typeMode)
	end
	rematch:UpdateBrowser()
end

function rematch:TypeBarTabOnClick()
	browser.typeMode = self:GetID()
	rematch:UpdateTypeBar()
end

function rematch:SearchBoxOnTextChanged()
	roster:SetSearch(self:GetText())
	rematch:UpdateBrowser()
end

--[[ Filter button UIDropDownMenu context menu ]]

-- generic func for dropdown option clicks
function rematch:ProcessDropDownOption(arg1,arg2,value)
	if self.value==COLLECTED then -- Collected
		C_PetJournal.SetFlagFilter(LE_PET_JOURNAL_FLAG_COLLECTED,value)
		if (value) then
			UIDropDownMenu_EnableButton(1,2)
		else
			UIDropDownMenu_DisableButton(1,2)
		end
	elseif self.value==FAVORITES_FILTER then -- Only Favorites
		roster:SetFavoriteFilter(value)
	elseif self.value==REMATCH_ONLY_LEVELING then -- Only Leveling
		roster:SetOnlyLevelingFilter(value)
	elseif self.value==NOT_COLLECTED then -- Not Collected
		C_PetJournal.SetFlagFilter(LE_PET_JOURNAL_FLAG_NOT_COLLECTED,value)
	elseif self.value==REMATCH_BROWSER_CURRENTZONE then
		roster:SetCurrentZoneFilter(value)
	elseif self.value==CHECK_ALL then -- Sources->Check All
		C_PetJournal.AddAllPetSourcesFilter()
		UIDropDownMenu_Refresh(browser.filterMenu,2,2)
	elseif self.value==UNCHECK_ALL then -- Sources->Uncheck All
		C_PetJournal.ClearAllPetSourcesFilter()
		UIDropDownMenu_Refresh(browser.filterMenu,2,2)
	elseif self.value==REMATCH_RESET and UIDROPDOWNMENU_MENU_LEVEL==3 then -- Reset on any of the three type menus
		local typeMode = UIDROPDOWNMENU_MENU_VALUE
		if roster:IsTypeFilterClear(typeMode) then
			for i=1,3 do -- manually clearing typeFilters to stay in same typeMode for dropdown menu
				roster:ClearTypeFilter(i)
			end
		else
			roster:ClearTypeFilter(typeMode)
		end
		UIDropDownMenu_Refresh(browser.filterMenu,2,2) -- refresh second-level menu (checks for type/strong/tough)
		UIDropDownMenu_Refresh(browser.filterMenu,3,3) -- refresh third-level menu (checks for 10 pet types)
	elseif self.value==REMATCH_RESET and UIDROPDOWNMENU_MENU_VALUE==4 then -- rarity filter
		roster:ClearRarityFilter()
		UIDropDownMenu_Refresh(browser.filterMenu,4,2)
	elseif self.value==REMATCH_BROWSER_RESETALL then
		rematch:ResetAllBrowserFilters()
		rematch:HideDropDown()
	else
--		print(self.value,UIDROPDOWNMENU_MENU_LEVEL,UIDROPDOWNMENU_MENU_VALUE)
		return
	end
	rematch:UpdateBrowser()
end

-- source filter menu clicks
function rematch:ProcessDropDownSource(_,_,value)
	C_PetJournal.SetPetSourceFilter(self.value,value)
	rematch:UpdateBrowser()
end
function rematch:CheckedDropDownSource(_,_,value)
	return not C_PetJournal.IsPetSourceFiltered(self.value)
end

-- pet type filter menu clicks
function rematch:ProcessDropDownTypeFilter(_,_,value)
	local typeMode = UIDROPDOWNMENU_MENU_VALUE
	roster:SetTypeFilter(typeMode,self.value,value)
	browser.typeMode = typeMode
	rematch:UpdateBrowser()
	UIDropDownMenu_Refresh(browser.filterMenu,2,2)
	UIDropDownMenu_Refresh(browser.filterMenu,3,3)
end
function rematch:CheckedDropDownTypeFilter(_,_,value)
	local typeMode = UIDROPDOWNMENU_MENU_VALUE
	if typeMode>1 or not roster:IsTypeFilterClear() then
		return roster:GetTypeFilter(typeMode,self.value)
	else
		return false
	end
end

function rematch:ProcessDropDownTypeMode(_,_,value)
	UIDropDownMenu_Refresh(browser.filterMenu,2,2) -- restore whatever user un/checked to actual value
end
function rematch:CheckedDropDownTypeMode(_,_,value)
	return not roster:IsTypeFilterClear(self.value)
end

function rematch:ProcessDropDownRarityFilter(_,_,value)
	roster:SetRarityFilter(self.value,value)
	rematch:UpdateBrowser()
end
function rematch:CheckedDropDownRarityFilter(_,_,value)
	return roster:GetRarityFilter(self.value)
end

-- sort filter menu clicks
function rematch:ProcessDropDownSort(_,_,value)
	C_PetJournal.SetPetSortParameter(self.value)
	UIDropDownMenu_Refresh(browser.filterMenu,2,2)
	rematch:UpdateBrowser()
end
function rematch:CheckedDropDownSort(_,_,value)
	return C_PetJournal.GetPetSortParameter() == self.value
end

function rematch:ProcessDropDownUseTypeBar(_,_,value)
	settings.UseTypeBar = value
	rematch:UpdateBrowser()
	if rematch.drawer.options:IsVisible() then
		rematch.drawer.options:Hide()
	end
end
function rematch:CheckedDropDownUseTypeBar(_,_,value)
	return settings.UseTypeBar
end

function rematch:BrowserFilterDropDownMenu(level,menuList)

	local info = UIDropDownMenu_CreateInfo()
	info.keepShownOnClick = true
	info.isNotRadio = true

	if (level or 1) == 1 then -- toplevel: collected/favorites/not collected/current zone/families>/sources>/rarity>/sort>

		info.text = COLLECTED
		info.func = rematch.ProcessDropDownOption
		info.checked = not C_PetJournal.IsFlagFiltered(LE_PET_JOURNAL_FLAG_COLLECTED);
		UIDropDownMenu_AddButton(info,level)
		info.text = FAVORITES_FILTER
		info.leftPadding = 8
		info.checked = roster:GetFavoriteFilter()
		UIDropDownMenu_AddButton(info,level)
		info.text = REMATCH_ONLY_LEVELING
		info.checked = roster:GetOnlyLevelingFilter()
		UIDropDownMenu_AddButton(info,level)
		info.text = NOT_COLLECTED
		info.leftPadding = nil
		info.checked = not C_PetJournal.IsFlagFiltered(LE_PET_JOURNAL_FLAG_NOT_COLLECTED)
		UIDropDownMenu_AddButton(info,level)

		info.text = REMATCH_BROWSER_CURRENTZONE
		info.checked = roster.GetCurrentZoneFilter
		UIDropDownMenu_AddButton(info,level)

		info.notCheckable = true
		info.func = nil
		info.hasArrow = true

		info.text = PET_FAMILIES
		info.value = 1
		UIDropDownMenu_AddButton(info,level)

		info.text = SOURCES
		info.value = 2
		UIDropDownMenu_AddButton(info,level)

		info.text = RARITY
		info.value = 4
		UIDropDownMenu_AddButton(info,level)

		info.text = RAID_FRAME_SORT_LABEL
		info.value = 3
		UIDropDownMenu_AddButton(info,level)

		info.hasArrow = nil
		info.text = REMATCH_BROWSER_RESETALL
		info.value = nil
		info.func = rematch.ProcessDropDownOption
		UIDropDownMenu_AddButton(info,level)

	elseif level==2 then

		if UIDROPDOWNMENU_MENU_VALUE == 1 then -- Pet Families

			info.hasArrow = true
			info.isNotRadio = true

			info.text = REMATCH_BROWSER_PETTYPE
			info.value = 1
			info.func = rematch.ProcessDropDownTypeMode
			info.checked = rematch.CheckedDropDownTypeMode
			UIDropDownMenu_AddButton(info,level)
			info.text = REMATCH_BROWSER_STRONGVS
			info.value = 2
			UIDropDownMenu_AddButton(info,level)
			info.text = REMATCH_BROWSER_TOUGHVS
			info.value = 3
			UIDropDownMenu_AddButton(info,level)

			info.text = REMATCH_BROWSER_USETYPEBAR
			info.func = rematch.ProcessDropDownUseTypeBar
			info.checked = rematch.CheckedDropDownUseTypeBar
			info.hasArrow = nil
			info.notCheckable = nil
			info.isNotRadio = true
			UIDropDownMenu_AddButton(info,level)

		elseif UIDROPDOWNMENU_MENU_VALUE == 2 then -- Sources

			info.notCheckable = true

			info.func = rematch.ProcessDropDownOption
			info.text = CHECK_ALL
			UIDropDownMenu_AddButton(info, level)

			info.text = UNCHECK_ALL
			UIDropDownMenu_AddButton(info, level)

			info.notCheckable = false
			info.func = rematch.ProcessDropDownSource
			info.checked = rematch.CheckedDropDownSource
			local numSources = C_PetJournal.GetNumPetSources()
			for i=1,numSources do
				info.text = _G["BATTLE_PET_SOURCE_"..i]
				info.value = i
				UIDropDownMenu_AddButton(info,level)
			end

		elseif UIDROPDOWNMENU_MENU_VALUE == 3 then -- Sort

			info.isNotRadio = nil
			info.func = rematch.ProcessDropDownSort
			info.checked = rematch.CheckedDropDownSort

			info.text = NAME
			info.value = LE_SORT_BY_NAME
			UIDropDownMenu_AddButton(info,level)

			info.text = LEVEL
			info.value = LE_SORT_BY_LEVEL
			UIDropDownMenu_AddButton(info,level)

			info.text = RARITY
			info.value = LE_SORT_BY_RARITY
			UIDropDownMenu_AddButton(info,level)

			info.text = TYPE
			info.value = LE_SORT_BY_PETTYPE
			UIDropDownMenu_AddButton(info,level)

		elseif UIDROPDOWNMENU_MENU_VALUE == 4 then -- Rarity

			info.isNotRadio = true
			info.notCheckable = false
			info.func = rematch.ProcessDropDownRarityFilter
			info.checked = rematch.CheckedDropDownRarityFilter

			for i=1,4 do
				info.text = _G["BATTLE_PET_BREED_QUALITY"..i]
				info.colorCode = "\124c"..select(4,GetItemQualityColor(i-1))
				info.value = i
				UIDropDownMenu_AddButton(info,level)
			end

			info.notCheckable = true
			info.text = REMATCH_RESET
			info.colorCode = nil
			info.value = nil
			info.func = rematch.ProcessDropDownOption
			UIDropDownMenu_AddButton(info,level)

		end

	elseif level==3 then -- Pet Families submenu (the 10 pet types)

		info.notCheckable = true

		if UIDROPDOWNMENU_MENU_VALUE==1 then
			info.text = REMATCH_BROWSER_PETTYPE
		elseif UIDROPDOWNMENU_MENU_VALUE==2 then
			info.text = "\124cff22dd22"..REMATCH_BROWSER_STRONGVS
		else
			info.text = "\124cffdd2222"..REMATCH_BROWSER_TOUGHVS
		end
		info.isTitle = true
		UIDropDownMenu_AddButton(info,level)

		info.isTitle = nil
		info.disabled = nil
		info.notCheckable = nil

		for i=1,C_PetJournal.GetNumPetTypes() do
			info.text = _G["BATTLE_PET_NAME_"..i]
			info.value = i
			info.func = rematch.ProcessDropDownTypeFilter
			info.checked = rematch.CheckedDropDownTypeFilter
			UIDropDownMenu_AddButton(info,level)
		end

		info.text = REMATCH_RESET
		info.value = nil
		info.notCheckable = true
		info.checked = nil
		info.func = rematch.ProcessDropDownOption
		UIDropDownMenu_AddButton(info,level)

	end
end

--[[ Results bar ]]

function rematch:UpdateBrowserResults()
	local bar = browser.resultsBar
	bar.count:SetText(format(REMATCH_BROWSER_RESULT_PETS,roster:GetNumPets()))
	local filters = roster:GetFilterResults()
	if filters then
		bar.owned:Hide()
		bar.filters:SetText(filters)
		bar.filters:Show()
		bar.filterClear:Show()
	else
		bar.filters:Hide()
		bar.filterClear:Hide()
		bar.owned:SetText(format(REMATCH_BROWSER_RESULT_OWNED,select(2,C_PetJournal.GetNumPets())))
		bar.owned:Show()
	end
end

function rematch:ResetAllBrowserFilters()
	rematch:HideDropDown()
	roster:ClearAllFilters()
	rematch:ClearSearchBox()
	rematch:BrowserScrollToTop()
end

